@@ -1,15 +1,15 @@
-# $Id: _Common.pm 85 2009-12-10 19:00:14Z cfaerber $
-
 package Unicode::Stringprep::_Common;
 
+require 5.8.3;
+
 use strict;
 use utf8;
 use warnings;
-require 5.006_000;
 
 use Exporter;
 
-our $VERSION = '1.01';
+our $VERSION = "1.10";
+$VERSION = eval { $VERSION };
 
 our @ISA = ('Exporter');
 our @EXPORT = ('_mk_set', '_mk_map');
@@ -25,10 +25,6 @@ sub _mk_set {
   return @data;
 };
 
-my $_mk_char = $] <= 5.008002
-  ? sub { eval '"\\x{'.(shift).'}"' }
-  : sub { chr(hex(shift)) };
-
 sub _mk_map {
   my @data = ();
   foreach my $line (split /\n/, shift) {
@@ -40,9 +36,9 @@ sub _mk_map {
         join('',map { 
 	  $_ eq '' 
 	    ? '' 
-	    : $_mk_char->($_)
+	    : chr(hex($_))
 	}
-	split(/ +/, $to));
+	split(' ', $to));
   }
   return @data;
 };
@@ -55,11 +51,11 @@ Unicode::Stringprep::_Common - Internal functions for C<Unicode::Stringprep::*>
 
 =head1 AUTHOR
 
-Claus Färber E<lt>CFAERBER@cpan.orgE<gt>
+Claus FE<auml>rber E<lt>CFAERBER@cpan.orgE<gt>
  
 =head1 LICENSE
  
-Copyright © 2007-2008 Claus Färber. All rights reserved.
+Copyright 2007-2009 Claus FE<auml>rber. All rights reserved.
  
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
